Index: drivers/dahdi/dahdi-base.c
===================================================================
--- drivers/dahdi/dahdi-base.c	(revision 7431)
+++ drivers/dahdi/dahdi-base.c	(working copy)
@@ -3434,6 +3434,27 @@ void dahdi_alarm_channel(struct dahdi_chan *chan,
 	spin_unlock_irqrestore(&chan->lock, flags);
 }
 
+/* 
+ * Set signalling on all channels to be on-hook.
+ */
+static void reset_span_to_onhook(struct dahdi_span *span)
+{
+	int x;
+
+	if (!span->rbsbits)
+		return;
+
+	for (x = 0; x < span->channels; x++) {
+		struct dahdi_chan *chan = span->chans[x];
+
+		if (!(chan->sig || (__DAHDI_SIG_FXS | __DAHDI_SIG_FXO | 
+				 DAHDI_SIG_EM | DAHDI_SIG_EM_E1)))
+			continue;
+		dahdi_rbsbits(chan, DAHDI_RXSIG_ONHOOK);
+	}
+}
+
+
 void dahdi_alarm_notify(struct dahdi_span *span)
 {
 	int x;
@@ -3460,6 +3482,9 @@ void dahdi_alarm_notify(struct dahdi_span *span)
 			}
 		}
 	}
+
+	if (span->alarms)
+		reset_span_to_onhook(span);
 }
 
 #define VALID_SPAN(j) do { \
